==> components-1.2.0.tgz: package/esm/Atoms/Buttons/Button.js <==
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: row;\n  justify-content: center;\n  align-items: center;\n  height: 2.5rem;\n  line-height: 2.5rem;\n  width: 100%;\n  padding: 0 1rem;\n  box-sizing: border-box;\n  color: ", ";\n  background-color: ", ";\n  border: none;\n  border-radius: ", ";\n  cursor: ", ";\n  outline: none;\n  transition: all 0.3s ease 0s;\n  opacity: ", ";\n  font-family: ", ";\n  font-size: 1rem;\n  font-weight: 600;\n\n  &:hover {\n    background-color: ", ";\n    transform: ", ";\n  }\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper = styled.button.attrs({
  type: function type(props) {
    return props.type;
  }
})(_templateObject(), function (props) {
  return props.theme['buttonColor'];
}, function (props) {
  return props.theme['buttonBackgroundColor'];
}, function (props) {
  return props.theme.buttonBorderRadius;
}, function (props) {
  return props.disabled ? 'not-allowed' : 'pointer';
}, function (props) {
  return props.disabled ? 0.5 : 1;
}, function (props) {
  return props.theme['fontPrimary'];
}, function (props) {
  return props.disabled ? props.theme['buttonBackgroundColor'] : props.theme['buttonHoverColor'];
}, function (props) {
  return props.bounced ? 'scale(0.95)' : 'none';
});

var Button = function Button(_ref) {
  var children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["children"]);

  return React.createElement(Wrapper, rest, children);
};

Button.propTypes = {
  bounced: PropTypes.bool,
  children: PropTypes.node,
  disabled: PropTypes.bool,
  type: PropTypes.oneOf(['button', 'reset', 'submit'])
};
Button.defaultProps = {
  bounced: false,
  disabled: false,
  type: 'button'
};
export default Button;

==> components-2.0.10.tgz: package/esm/Atoms/Buttons/Button.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper =
/*#__PURE__*/
styled.button.attrs({
  type: function type(props) {
    return props.type;
  }
}).withConfig({
  componentId: "sc-1t2k7dn-0"
})(["display:flex;flex-direction:row;justify-content:center;align-items:center;height:2.5rem;line-height:2.5rem;width:100%;padding:0 1rem;box-sizing:border-box;color:", ";background-color:", ";border:none;border-radius:", ";cursor:", ";outline:none;transition:all 0.3s ease 0s;opacity:", ";font-family:", ";font-size:1rem;font-weight:600;&:hover{background-color:", ";transform:", ";}"], function (props) {
  return props.theme['buttonColor'];
}, function (props) {
  return props.theme['buttonBackgroundColor'];
}, function (props) {
  return props.theme.buttonBorderRadius;
}, function (props) {
  return props.disabled ? 'not-allowed' : 'pointer';
}, function (props) {
  return props.disabled ? 0.5 : 1;
}, function (props) {
  return props.theme['fontPrimary'];
}, function (props) {
  return props.disabled ? props.theme['buttonBackgroundColor'] : props.theme['buttonHoverColor'];
}, function (props) {
  return props.bounced ? 'scale(0.95)' : 'none';
});

var Button = function Button(_ref) {
  var children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["children"]);

  return React.createElement(Wrapper, rest, children);
};

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  bounced: PropTypes.bool,
  children: PropTypes.node,
  disabled: PropTypes.bool,
  type: PropTypes.oneOf(['button', 'reset', 'submit'])
} : {};
Button.defaultProps = {
  bounced: false,
  disabled: false,
  type: 'button'
};
export default Button;
